@@ -190,8 +190,7 @@ mod tests {
 
 pub mod scfmt {
 
-    use colored::*;
-    use glob::glob;
+    use glob::{glob, GlobError};
     use phf::phf_map;
     use std::fs;
     use std::fs::File;
@@ -340,7 +339,7 @@ pub mod scfmt {
         whitespace + &str_no_whitespace
     }
 
-    pub fn get_files_in_dir(path: &str, filetype: &str) -> Vec<PathBuf> {
+    pub fn get_files_in_dir(path: &str, filetype: &str) -> Result<Vec<PathBuf>, GlobError> {
         //> get list of all files and dirs in path, using glob
             let mut paths = Vec::new();
 
@@ -356,7 +355,7 @@ pub mod scfmt {
                     Ok(path) => {
                         paths.push(path);
                     }
-                    Err(e) => println!("{:?}", e),
+                    Err(e) => return Err(e),
                 }
             }
 
@@ -369,12 +368,12 @@ pub mod scfmt {
                 .filter(|e| fs::read_to_string(e).is_ok())
                 .collect();
         //<
-        paths
+        Ok(paths)
     }
 
     fn ensure_previous_lines_have_correct_indentation(
-        formatted_lines: &mut Vec<String>,
-        comment_tracker: &mut Vec<CommentDetail>,
+        formatted_lines: &mut [String],
+        comment_tracker: &mut [CommentDetail],
         tab_spaces: usize,
         whitespace_char: char,
     ) {
@@ -548,14 +547,13 @@ pub mod scfmt {
 
                     // remove comment from comment tracker
                     comment_tracker.pop();
+                } else if leading_spaces != None {
+                    formatted_lines.push(line.to_string() + "\n");
                 } else {
-                    if leading_spaces != None {
-                        formatted_lines.push(line.to_string() + "\n");
-                    } else {
-                        // all whitespace only lines are set to depth 0
-                        formatted_lines.push("\n".to_string());
-                    }
+                    // all whitespace only lines are set to depth 0
+                    formatted_lines.push("\n".to_string());
                 }
+
             //<
         }
 
@@ -584,94 +582,72 @@ pub mod scfmt {
         Ok(formatted_file)
     }
 
-    fn display_err(err: (usize, String), file: PathBuf) {
-        if err.1 != "Incompatible file type" {
-            println!("{}: {}", "error".red().bold(), err.1);
-            println!(
-                "{}",
-                file.as_os_str().to_str().unwrap().to_owned() + ":" + &format!("{}", err.0)
-            );
-        }
-    }
-
-    pub fn format_file(file: PathBuf) -> bool {
+    pub fn format_file(file: PathBuf) -> Result<(), (usize, String)> {
         let extenstion = match file.extension() {
             Some(x) => match x.to_str() {
                 Some(x) => x,
-                None => return false,
+                None => return Err((0, "Cannot convert OS String to displayable".to_owned())),
             },
-            None => return false,
+            None => return Err((0, "Cannot determine file extension".to_owned())),
         };
 
         let contents = match fs::read_to_string(&file) {
             Ok(x) => x,
-            Err(_) => return false,
+            Err(_) => return Err((0, "Cannot read file as string".to_owned())),
         };
 
-        let formatted = match format_str(&contents, extenstion) {
-            Ok(x) => x,
-            Err(err) => {
-                display_err(err, file);
-                return false;
-            }
-        };
-
-        //> write file
-            // leave file alone if there was no change
-            if formatted != contents {
-                let mut output = match File::create(file) {
-                    Ok(x) => x,
-                    Err(_) => return false,
-                };
-
-                match write!(output, "{}", formatted) {
-                    Ok(x) => x,
-                    Err(_) => return false,
-                };
-            }
-        //<
-
-        true
-    }
-
-    pub fn add_brackets_file(file: PathBuf) -> bool {
-        let extenstion = match file.extension() {
-            Some(x) => match x.to_str() {
-                Some(x) => x,
-                None => return false,
-            },
-            None => return false,
-        };
-
-        let contents = match fs::read_to_string(&file) {
-            Ok(x) => x,
-            Err(_) => return false,
-        };
-
-        let converted = match add_brackets(&contents, extenstion) {
-            Ok(x) => x,
-            Err(err) => {
-                display_err(err, file);
-                return false;
-            }
-        };
+        let converted = format_str(&contents, extenstion)?;
 
         //> write file
             // leave file alone if there was no change
             if converted != contents {
                 let mut output = match File::create(file) {
                     Ok(x) => x,
-                    Err(_) => return false,
+                    Err(_) => return Err((0, "Cannot create file".to_owned())),
                 };
 
                 match write!(output, "{}", converted) {
                     Ok(x) => x,
-                    Err(_) => return false,
+                    Err(_) => return Err((0, "Cannot write to file".to_owned())),
                 };
             }
         //<
 
-        true
+        Ok(())
+    }
+
+    pub fn add_brackets_file(file: PathBuf) -> Result<(), (usize, String)> {
+        let extenstion = match file.extension() {
+            Some(x) => match x.to_str() {
+                Some(x) => x,
+                None => return Err((0, "Cannot convert OS String to displayable".to_owned())),
+            },
+            None => return Err((0, "Cannot determine file extension".to_owned())),
+        };
+
+        let contents = match fs::read_to_string(&file) {
+            Ok(x) => x,
+            Err(_) => return Err((0, "Cannot read file as string".to_owned())),
+        };
+
+        let converted = add_brackets(&contents, extenstion)?;
+
+        //> write file
+            // leave file alone if there was no change
+            if converted != contents {
+                let mut output = match File::create(file) {
+                    Ok(x) => x,
+                    Err(_) => return Err((0, "Cannot create file".to_owned())),
+                };
+
+                match write!(output, "{}", converted) {
+                    Ok(x) => x,
+                    Err(_) => return Err((0, "Cannot write to file".to_owned())),
+                };
+            }
+        //<
+
+        Ok(())
     }
 
     struct CommentDetail {
@@ -786,17 +762,14 @@ pub mod scfmt {
         // chop off begining spaces
         let (leading_whitespace_option, line_no_leading_spaces) = chop_off_beginning_spaces(line);
 
-        match leading_whitespace_option {
-            Some(num_leading_whitespace) => {
-                Some((num_leading_whitespace, line_no_leading_spaces.to_owned()))
-            }
-            None => None,
-        }
+        leading_whitespace_option.map(|num_leading_whitespace| {
+            (num_leading_whitespace, line_no_leading_spaces.to_owned())
+        })
     }
 
     fn last_non_empty_line_before_index(
         index: usize,
-        lines_list: &Vec<String>,
+        lines_list: &[String],
     ) -> Option<(usize, &str)> {
         for i in (0..index).rev() {
             if !line_is_only_whitepace(&lines_list[i]) {
@@ -809,7 +782,7 @@ pub mod scfmt {
 
     fn add_open_bracket_to_last_comment(
         lines_list: &mut Vec<String>,
-        comment_tracker: &mut Vec<CommentDetail>,
+        comment_tracker: &mut [CommentDetail],
         comment_starter: &str,
     ) {
         let mut should_consume_closing_comment = false;
@@ -1041,7 +1014,7 @@ pub mod scfmt {
                     }
                 }
                 None => {
-                    lines_list.push(String::from("".to_owned()));
+                    lines_list.push("".to_owned());
                 }
             }
         }
@@ -1124,12 +1097,10 @@ pub mod scfmt {
                     depth,
                     whitespace_char,
                 ));
+            } else if line_is_only_whitepace(line) {
+                lines_list.push("".to_owned());
             } else {
-                if line_is_only_whitepace(line) {
-                    lines_list.push("".to_owned());
-                } else {
-                    lines_list.push(line.to_owned());
-                }
+                lines_list.push(line.to_owned());
             }
         }
 
@@ -1171,44 +1142,38 @@ pub mod scfmt {
         count
     }
 
-    pub fn remove_brackets_file(file: PathBuf) -> bool {
+    pub fn remove_brackets_file(file: PathBuf) -> Result<(), (usize, String)> {
         let extenstion = match file.extension() {
             Some(x) => match x.to_str() {
                 Some(x) => x,
-                None => return false,
+                None => return Err((0, "Cannot convert OS String to displayable".to_owned())),
             },
-            None => return false,
+            None => return Err((0, "Cannot determine file extension".to_owned())),
         };
 
         let contents = match fs::read_to_string(&file) {
             Ok(x) => x,
-            Err(_) => return false,
+            Err(_) => return Err((0, "Cannot read file as string".to_owned())),
         };
 
-        let converted = match remove_brackets(&contents, extenstion) {
-            Ok(x) => x,
-            Err(err) => {
-                display_err(err, file);
-                return false;
-            }
-        };
+        let converted = remove_brackets(&contents, extenstion)?;
 
         //> write file
             // leave file alone if there was no change
             if converted != contents {
                 let mut output = match File::create(file) {
                     Ok(x) => x,
-                    Err(_) => return false,
+                    Err(_) => return Err((0, "Cannot create file".to_owned())),
                 };
 
                 match write!(output, "{}", converted) {
                     Ok(x) => x,
-                    Err(_) => return false,
+                    Err(_) => return Err((0, "Cannot write to file".to_owned())),
                 };
             }
         //<
 
-        true
+        Ok(())
     }
 
     pub fn null_existing_brackets_file(file: PathBuf) -> bool {
@@ -1228,7 +1193,6 @@ pub mod scfmt {
         let converted = match null_existing_brackets(&contents, extenstion) {
             Some(x) => x,
             None => {
-                // display_err("err", file);
                 return false;
             }
         };
@@ -1276,8 +1240,8 @@ pub mod scfmt {
                 let comment_starter_with_space = comment_starter.to_owned() + " ";
                 if str.starts_with(&comment_starter_with_space) {
                     line_no_comment_starter = &str[comment_starter.len() + 1..];
-                } else if str.starts_with(comment_starter) {
-                    line_no_comment_starter = &str[comment_starter.len()..];
+                } else if let Some(stripped) = str.strip_prefix(comment_starter) {
+                    line_no_comment_starter = stripped;
                 }
 
                 line_no_comment_starter.to_string()
@@ -1286,7 +1250,7 @@ pub mod scfmt {
         }
     }
 
-    fn count_ending_empty_lines(lines_list: &Vec<String>) -> usize {
+    fn count_ending_empty_lines(lines_list: &[String]) -> usize {
         let mut count = 0;
         for i in (0..lines_list.len()).rev() {
             if !line_is_only_whitepace(&lines_list[i]) {
@@ -1336,18 +1300,19 @@ pub mod scfmt {
                     let line_no_comment_starter =
                         remove_comment_starter(line_no_leading_whitespace, comment_starter);
 
-                    if line_no_comment_starter.starts_with("<>") {
+                    if let Some(line_no_brackets) = line_no_comment_starter.strip_prefix("<>") {
                         lines_list.push(
                             add_whitespace(
-                                &(comment_starter.to_owned() + &line_no_comment_starter[2..]),
+                                &(comment_starter.to_owned() + line_no_brackets),
                                 leading_whitespace,
                                 whitespace_char,
                             ) + "\n",
                         );
-                    } else if line_no_comment_starter.starts_with('>') {
+                    } else if let Some(line_no_brackets) = line_no_comment_starter.strip_prefix('>')
+                    {
                         lines_list.push(
                             add_whitespace(
-                                &(comment_starter.to_owned() + &line_no_comment_starter[1..]),
+                                &(comment_starter.to_owned() + line_no_brackets),
                                 leading_whitespace,
                                 whitespace_char,
                             ) + "\n",
